@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: imp/thread.php,v 2.10.2.27 2008/08/28 09:16:06 jan Exp $
+ * $Horde: imp/thread.php,v 2.10.2.30 2010/07/01 20:00:26 slusarz Exp $
  *
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -17,6 +17,8 @@ require_once IMP_BASE . '/lib/Message.php';
 require_once IMP_BASE . '/lib/MIME/Contents.php';
 require_once IMP_BASE . '/lib/Template.php';
 
+$dnsnoprefetch = true;
+
 /* What mode are we in?
  * DEFAULT/'thread' - Thread mode
  * 'msgview' - Multiple message view
@@ -96,6 +98,10 @@ foreach ($loop_array as $mbox => $idxlist) {
         /* Get the body of the message. */
         $curr_msg = $curr_tree = array();
         $contents = &IMP_Contents::singleton($idx . IMP_IDX_SEP . $mbox);
+        if (is_a($contents, 'PEAR_Error')) {
+            $notification->push($contents, 'horde.error');
+            continue;
+        }
         $mime_id = $contents->findBody();
         $mime_part = $contents->getDecodedMIMEPart($mime_id);
         if ($contents->canDisplayInline($mime_part)) {
